mercurial/localrepo.py
changeset 13357 b67867940bd1
parent 13356 d96db730fcb2
child 13358 f26a51857dc7
--- a/mercurial/localrepo.py	Thu Feb 10 13:46:27 2011 -0600
+++ b/mercurial/localrepo.py	Thu Feb 10 13:46:27 2011 -0600
@@ -987,7 +987,11 @@
                         _('note: commit message saved in %s\n') % msgfn)
                 raise
 
-            # update dirstate and mergestate
+            # update bookmarks, dirstate and mergestate
+            parents = (p1, p2)
+            if p2 == nullid:
+                parents = (p1,)
+            bookmarks.update(self, parents, ret)
             for f in changes[0] + changes[1]:
                 self.dirstate.normal(f)
             for f in changes[2]: